@@ -488,9 +488,11 @@ class Row(object):
     date = None
     unit_code = None
     freetext = None
+    article_identifier = None
 
     def __init__(self, row):
         self.name = row.ArticleNameSet.as_string()
+        self.article_identifier = row.ArticleIdentifierSet.as_string()
 
         def get_QuantitySetData(set):
             if len(set) > 0:
@@ -572,6 +574,7 @@ class Row(object):
     def dict(self):
         return {
             'name': self.name,
+            'article_identifier': self.article_identifier,
             'quantity': self.quantity,
             'unit_price': self.unit_price,
             'total_taxed': self.total_taxed,
